==> Mudlib-CD.00.28.tar.gz: lib/std/player_pub.c <==
/*

  player_pub.c

  This is the customizable part of the old player.c. Inherit this object
  to make your race object. That race dependant object should then be 
  inherited by the guild dependant object. 

  This file inherits the player_sec object statically to ensure the 
  protection of all lower level routines.

*/
#pragma save_binary

#include <macros.h>
#include <composite.h>
#include <config.h>

inherit "/std/player_sec";

/*
 * Prototypes
 */
object *local_rooms(object from_room, int depth);
object *add_rooms(object loc, int depth, object preloc);

public int
check_player_pub() { return 1; }  /* Security, checked by /secure/login */

public void
start_player()
{
    /* Get the soul commands */
    this_object()->load_command_souls();
    command("look");
    say(QCNAME(this_object()) + " enters the game.\n");
}

/*
 * Function name: death_modify_stat
 * Description:   Modification function for free stats on death
 * Returns:       The modified stat.
 */
static int
death_modify_stat(int stat) { return query_stat(stat); }

/*
 * Function name: death_sequence
 * Description:   Defines what happens to the player after death
 */
static void
death_sequence()
{
    object death_mark;
    if (!query_ghost()) return;
    
    death_mark = clone_object(DEFAULT_DEATH);
    death_mark->move(this_object(), 1);
}


/*
 * Function name: tell_leader
 * Description:   Tells this player who follows him when he leaves
 */
public void
tell_leader(object *team, string where)
{
/* I think these comments aren't needed since you get arrive messages mostly.
 * And if you cannot see the player, well, what the heck. /Nick
    
    tell_object(this_object(), (string) COMPOSITE_FILE->desc_live(team) +
		" followed you.\n");
 */
}

/*
 * Function name: tell_member
 * Description:   Tells this player that he follows his leader
 */
public void
tell_member(object leader, string where)
{
/*
    tell_object(this_object(), "You follow " +
	COMPOSITE_FILE->desc_live(leader) + ".\n");
*/
}

/*
 * Function:    query_new_title
 * Description: Returns the title of the player calculated from stats
 *
 */
public string
query_new_title()
{
    return "the utter novice";
}

/*
 * Function:    query_new_al_title
 * Description: Returns the al_title of the player calculated from stats
 *
 */
public string
query_new_al_title()
{
    return "neutral";
}

public int *
query_orig_stat()
{
    /*        STR, DEX, CON, INT, WIS, DIS */
    return ({ 10,  10,  10,  10,  10,  10 });
}

public int *
query_orig_learn()
{
    /*        STR, DEX, CON, INT, WIS, DIS */
    return ({ 20,  16,  16,  16,  16,  16 });
}

static string more_file;	/* Used by the more command */
static int    more_line,
    	      chunk;

varargs int
more(string file, int start, int size)
{
    object          ob;
    int             temp;

    more_file = file;

    if (start)
	more_line = start;
    else
	more_line = 1;

    if (size)
	chunk = size;
    else
	chunk = 17;

    if (cat(more_file, more_line, chunk) >= chunk)
    {
	input_to("even_more");
	write("More: --" + (more_line + chunk + 1) + "-- <cr>,d,u,b,#,q> ");
    }
    return 1;
}

static int
even_more(string str)
{
    int             cnt;

    if (str == "d")
    {
	more_line += 4;
    }
    if (str == "")
    {
	more_line += chunk;
    }
    if (str == "q")
    {
	write("Ok.\n");
	return 1;
    }
    if (str == "b")
    {
	more_line -= 4;
	if (more_line < 1)
	{
	    more_line = 1;
	}
    }
    if (str == "u")
    {
	more_line -= chunk;
	if (more_line < 1)
	{
	    more_line = 1;
	}
    }
    if (str && sscanf(str, "%d", cnt) == 1)
    {
	more_line = cnt;
	if (more_line < 1)
	{
	    more_line = 1;
	}
    }
    if (cat(more_file, more_line, chunk) == 0)
    {
	more_file = 0;
	write("EOF\n");
	return 1;
    }
    write("More: --" + (more_line + chunk) + "-- <cr>,d,u,b,#,q> ");
    input_to("even_more");
    return 1;
}

==> Mudlib-CD.00.30.tar.gz: lib/std/player_pub.c <==
/*

  player_pub.c

  This is the customizable part of the old player.c. Inherit this object
  to make your race object. That race dependant object should then be 
  inherited by the guild dependant object. 

  This file inherits the player_sec object statically to ensure the 
  protection of all lower level routines.

*/
#pragma save_binary

#include <macros.h>
#include <composite.h>
#include <config.h>

inherit "/std/player_sec";

/*
 * Prototypes
 */
object *local_rooms(object from_room, int depth);
object *add_rooms(object loc, int depth, object preloc);

public int
check_player_pub() { return 1; }  /* Security, checked by /secure/login */

public void
start_player()
{
    /* Get the soul commands */
    this_object()->load_command_souls();
    command("look");
    say(QCNAME(this_object()) + " enters the game.\n");
}

/*
 * Function name: death_modify_stat
 * Description:   Modification function for free stats on death
 * Returns:       The modified stat.
 */
int
death_modify_stat(int stat) { return query_stat(stat); }

/*
 * Function name: death_sequence
 * Description:   Defines what happens to the player after death
 */
void
death_sequence()
{
    object death_mark;
    if (!query_ghost()) return;
    
    death_mark = clone_object(DEFAULT_DEATH);
    death_mark->move(this_object(), 1);
}


/*
 * Function name: tell_leader
 * Description:   Tells this player who follows him when he leaves
 */
public void
tell_leader(object *team, string where)
{
/* I think these comments aren't needed since you get arrive messages mostly.
 * And if you cannot see the player, well, what the heck. /Nick
    
    tell_object(this_object(), (string) COMPOSITE_FILE->desc_live(team) +
		" followed you.\n");
 */
}

/*
 * Function name: tell_member
 * Description:   Tells this player that he follows his leader
 */
public void
tell_member(object leader, string where)
{
/*
    tell_object(this_object(), "You follow " +
	COMPOSITE_FILE->desc_live(leader) + ".\n");
*/
}

/*
 * Function:    query_new_title
 * Description: Returns the title of the player calculated from stats
 *
 */
public string
query_new_title()
{
    return "the utter novice";
}

/*
 * Function:    query_new_al_title
 * Description: Returns the al_title of the player calculated from stats
 *
 */
public string
query_new_al_title()
{
    return "neutral";
}

public int *
query_orig_stat()
{
    /*        STR, DEX, CON, INT, WIS, DIS */
    return ({ 10,  10,  10,  10,  10,  10 });
}

public int *
query_orig_learn()
{
    /*        STR, DEX, CON, INT, WIS, DIS */
    return ({ 20,  16,  16,  16,  16,  16 });
}

static string more_file;	/* Used by the more command */
static int    more_line,
    	      chunk;

varargs int
more(string file, int start, int size)
{
    object          ob;
    int             temp;

    more_file = file;

    if (start)
	more_line = start;
    else
	more_line = 1;

    if (size)
	chunk = size;
    else
	chunk = 17;

    if (cat(more_file, more_line, chunk) >= chunk - 1) //Kludge for cat()
    {
	input_to("even_more");
	write("More: --" + (more_line + chunk + 1) + "-- <cr>,d,u,b,#,q> ");
    }
    return 1;
}

nomask int
even_more(string str)
{
    int             cnt;

    if (str == "d")
    {
	more_line += 4;
    }
    if (str == "")
    {
	more_line += chunk;
    }
    if (str == "q")
    {
	write("Ok.\n");
	return 1;
    }
    if (str == "b")
    {
	more_line -= 4;
	if (more_line < 1)
	{
	    more_line = 1;
	}
    }
    if (str == "u")
    {
	more_line -= chunk;
	if (more_line < 1)
	{
	    more_line = 1;
	}
    }
    if (str && sscanf(str, "%d", cnt) == 1)
    {
	more_line = cnt;
	if (more_line < 1)
	{
	    more_line = 1;
	}
    }
    if (cat(more_file, more_line, chunk) == 0)
    {
	more_file = 0;
	write("EOF\n");
	return 1;
    }
    write("More: --" + (more_line + chunk) + "-- <cr>,d,u,b,#,q> ");
    input_to("even_more");
    return 1;
}
